package model.core;

import javax.persistence.*;
import java.io.*;
import java.util.*;

@Entity
@Table(name = "Categories")
@SequenceGenerator(name = "seqId", sequenceName = "seqCategoriesId")

public class Category implements Serializable {

    @Id
    @Column(name = "categoryId", nullable = false, unique = true)
    @GeneratedValue(strategy = GenerationType.AUTO, generator = "seqId")
    private Integer id;

    @Column
    private String name;
    
    @ManyToMany(fetch = FetchType.EAGER)
    @JoinTable(
        name = "CategoriesProducts",
        joinColumns = {
            @JoinColumn(name = "categoryId")
        },
        inverseJoinColumns = {
            @JoinColumn(name = "productId")
        }
    )
    private Set<Product> products = new HashSet();

    
    public Integer getId() { return this.id; }
    private void setId(Integer id) { this.id = id; }

    public String getName() { return this.name; }
    public void setName(String name) { this.name = name; }

    public Set<Product> getProducts() { return this.products; }

    public void add(Product product) {
        
        this.products.add(product);

        if (!product.getCategories().contains(this)) {
            product.getCategories().add(this);
        }

        model.manager.CategoryManager.update(this);
    
    }



}
