package model.core;

import javax.persistence.*;
import java.util.*;

@Entity
@Table(name = "Products")
@SequenceGenerator(name = "seqId", sequenceName = "seqProductId")

@NamedQueries({

    @NamedQuery(
        name = "getLatest",
        query = "SELECT product FROM Product product ORDER BY product.id DESC"
    )

})

public class Product {

    @Id
    @Column(name = "productId", nullable = false, unique = true)
    @GeneratedValue(strategy = GenerationType.AUTO, generator = "seqId")
    private Integer id;

    @Column
    private String title;
    
    @Column
    private String author;
    
    @Column
    private String press;
    
    @Column(unique = true)
    private String ISBN;
    
    @Column
    private String price;
    
    @Column
    private String fileFormat;
    
    @Column
    private String imageFormat;
    
    @Column
    private String edition;

    @Lob
    private String description;

    @ManyToMany(mappedBy = "products", fetch = FetchType.EAGER)
    private Set<Purchase> purchases = new HashSet();

    @ManyToMany(mappedBy = "products", fetch = FetchType.EAGER)
    private Set<Category> categories = new HashSet();


    public Product() { }


    public Integer getId() { return id; }
    private void setId(Integer id) { this.id = id; }

    public String getISBN() { return ISBN; }
    public void setISBN(String ISBN) { this.ISBN = ISBN; }

    public String getAuthor() { return author; }
    public void setAuthor(String author) { this.author = author; }

    public String getEdition() { return this.edition; }
    public void setEdition(String edition) { this.edition = edition; }

    public String getFileFormat() { return this.fileFormat; }
    public void setFileFormat(String fileFormat) { 
        this.fileFormat = fileFormat; 
    }

    public String getImageFormat() { return this.imageFormat; }
    public void setImageFormat(String imageFormat) { 
        this.imageFormat = imageFormat;
    }

    public String getPress() { return press; }
    public void setPress(String press) { this.press = press; }

    public String getPrice() { return price; }
    public void setPrice(String price) { this.price = price; }

    public String getTitle() { return title; }
    public void setTitle(String title) { this.title = title; }

    public String getDescription() { return this.description; }
    public void setDescription(String description) {
        this.description = description;
    }

    public Set<Purchase> getPurchases() { return this.purchases; }

    public Set<Category> getCategories() { return this.categories; }


    public void add(Purchase purchase) {
        
        this.purchases.add(purchase);
    
        if (!purchase.getProducts().contains(this)) {
            purchase.getProducts().add(this);
        }

        model.manager.ProductManager.update(this);

    }

    public void add(Category category) {
        
        this.categories.add(category);
    
        if (!category.getProducts().contains(this)) {
            category.getProducts().add(this);
        }

        model.manager.ProductManager.update(this);

    }


}
