package model.core;

import java.util.*;
import javax.persistence.*;
import java.io.*;

@Entity
@Table(name = "Purchases")
@SequenceGenerator(name = "seqId", sequenceName = "seqPurchasesId")

@NamedQueries({

    @NamedQuery(
        name = "findNotPaid",
        query = "SELECT p FROM Purchase p WHERE p.paid = :paid"
    )
})

public class Purchase implements Serializable {
    
    @Id
    @Column(name = "purchaseId",  nullable = false, unique = true)
    @GeneratedValue(strategy = GenerationType.AUTO, generator = "seqId")
    private Integer id;

    @Column(nullable = false)
    private Boolean paid;

    @Column
    private Long date;

    @Column
    private String paymentType;

    @ManyToOne(fetch = FetchType.EAGER)
    @JoinColumn(name = "userId")
    private User user;

    @ManyToMany(fetch = FetchType.EAGER)
    @JoinTable(
        name = "ProductsPurchases",
        joinColumns = {
            @JoinColumn(name = "purchaseId")
        },
        inverseJoinColumns = {
            @JoinColumn(name = "productId")
        }
    )
    private Set<Product> products = new HashSet();


    public Purchase() { }

    public Integer getId() { return this.id; }
    private void setId(Integer id) { this.id = id; }

    public Boolean isPaid() { return this.paid; }
    public void setPaid(Boolean paid) { this.paid = paid; }

    public Long getDate() { return this.date; }
    public void setDate(Long date) { this.date = date; }

    public String getPaymentType() { return this.paymentType; }
    public void setPaymentType(String paymentType) { 
        this.paymentType = paymentType;
    }

    public User getUser() { return this.user; }
    public void setUser(User user) { this.user = user; }

    public Set<Product> getProducts() { return this.products; }

    public void add(Product product) {
        
        this.products.add(product);

        if (!product.getPurchases().contains(this)) {
            product.getPurchases().add(this);
        }

        model.manager.PurchaseManager.update(this);
    }

    
    private static void unitTest1() {
        
        Product product1 = new Product();
        product1.setTitle("product1");

        model.manager.ProductManager.add(product1);

        Purchase purchase1 = new Purchase();

        purchase1.setPaymentType("cartao1");
        purchase1.setPaid(false);

        model.manager.PurchaseManager.add(purchase1);

        purchase1.add(product1);

        System.out.println("Purchases size: " + product1.getPurchases().size());

        System.out.println("Purchases size: " + model.manager.ProductManager.findById(product1.getId()).getPurchases().size());

    }

    public static void main(String args[]) {
    
        Purchase.unitTest1();
    
    }



}
