package model.manager;

import java.util.*;
import org.hibernate.*;
import model.util.*;
import model.core.*;

public class ProductManager {

    public static void add(Product product) {

        // Get database connection
        Session session = HibernateUtil.getSession();

        // Save product to database
        session.beginTransaction();
        session.save(product);
        session.getTransaction().commit();

    }

    public static void remove(int productId) {
    
         // Get database connection
        Session session = HibernateUtil.getSession();

        // Delete product from database
        session.beginTransaction();
        Object product = session.get(Product.class, new Integer(productId));
        session.delete(product);
        session.getTransaction().commit();
    
    }

    public static void remove(Product product) {
    
         // Get database connection
        Session session = HibernateUtil.getSession();

        // Delete product from database
        session.beginTransaction();
        session.delete(product);
        session.getTransaction().commit();

    }

    public static void update(Product product) {
    
        // Get database connection
        Session session = HibernateUtil.getSession();

        // Update product in database
        session.beginTransaction();
        session.update(product);
        session.getTransaction().commit();
    
    }

    public static Product findById(int id) {
        
        // Get database connection
        Session session = HibernateUtil.getSession();

        // Load from database
        session.beginTransaction();
        Product product = (Product) session.get(Product.class, new Integer(id));
        session.getTransaction().commit();

        return product;

    }


    /**
     * Get the latest additions to the database, i.e., the newest products.
     *
     * @param maxResults Number of results to be retrieved.
     * @return An array list of products with latest ones.
     */
    public static ArrayList<Product> getLatest(int maxResults) {
        
        ArrayList<Product> latest = new ArrayList();
        
        // Get database connection
        Session session = HibernateUtil.getSession();  
        session.beginTransaction();

        // Load query from annotations by name
        org.hibernate.Query query = session.getNamedQuery("getLatest");

        // Limit retrieval to only last maxResults results
        query.setMaxResults(maxResults);

        // For each retrieved result
        for (Iterator iterator = query.iterate(); iterator.hasNext(); ) {
            
            // Add to array
            latest.add((Product) iterator.next());

        }

        session.getTransaction().commit();


        return latest;

    }

    private static void unitTest1() {
      
        Product product1 = new Product();
        product1.setTitle("Teste1");
        Product product2 = new Product();
        product2.setTitle("Teste2");
        Product product3 = new Product();
        product3.setTitle("Teste3");
        Product product4 = new Product();
        product4.setTitle("Teste4");
        Product product5 = new Product();
        product5.setTitle("Teste5");

        ProductManager.add(product1);
        ProductManager.add(product2);
        ProductManager.add(product3);
        ProductManager.add(product4);
        ProductManager.add(product5);

        ArrayList<Product> products = ProductManager.getLatest(3);

        for (int i = 0; i < products.size(); i++ ) {
        
            Product product = (Product) products.get(i);
        
            System.out.println("Title: " + product.getTitle());
        
        }

    }

    public static void main(String args[]) {
        ProductManager.unitTest1();
    }

}
