package model.manager;

import java.security.*;
import org.hibernate.*;
import model.core.*;
import model.util.*;

public class UserManager {
  
    
    public static void add(User user) {

        // Get database connection
        Session session = HibernateUtil.getSession();

        // Save user to database
        session.beginTransaction();
        session.save(user);
        session.getTransaction().commit();

    }


    public static void update(User user) {

        // Get database connection
        Session session = HibernateUtil.getSession();

        // Save user to database
        session.beginTransaction();
        session.update(user);
        session.getTransaction().commit();


    }


    /**
      * Retrieve an user from database, checking its email and password.
      *
      * @param email    User's mail string.
      * @param password User's password string.
      * @return User corresponding to given email and password.
      */
    public static User findByEmailPassword(String email, String password) {

        String hashedPassword = null;

        try {

            // Get a message digestor implementing the SHA-1 algorithm 
            MessageDigest sha = MessageDigest.getInstance("SHA");

            // Make a hash of password and store it as a String
            hashedPassword = new String(sha.digest(password.getBytes()), "UTF-8");

        } catch (Exception exception) {
            // Ignore exception as they will never happen
        }

        // Get database connection
        Session session = HibernateUtil.getSession();
        session.beginTransaction();

        // Load query as specified in annotations by its name
        org.hibernate.Query query = session.getNamedQuery("findByEmailPassword");

        // Prepare query with parameters
        query.setString("email", email);
        query.setString("password", hashedPassword);

        // Execute query returning a single result: the user we are looking for
        User user = (User) query.uniqueResult();
        
        // Commit transaction
        session.getTransaction().commit();
        
        return user;
    }




    private static void unitTest1() {

        User user = new User();
        user.setFirstName("firstName");
        user.setSurname("surname");
        user.setEmail("email");
        user.setPassword("password");
        user.setAdmin(false);

        UserManager.add(user);

        if (UserManager.findByEmailPassword("email", "password") != null) {
            System.out.println("Test1: Successful");
        } else {
            System.out.println("Test1: Failed");
        }

    }

    public static void main (String args[]) {
        UserManager.unitTest1();
    }
}

